pygeodesy.namedTuples.LatLon3Tuple

Package pygeodesy :: Module namedTuples :: Class LatLon3Tuple |
[frames] | no frames]

# Class LatLon3Tuple

       object --+
                |
            tuple --+
                    |
       object --+   |
                |   |
     named._Named --+
                    |
    named._NamedTuple --+
                        |
                       LatLon3Tuple

Known Subclasses:
  - LatLon4Tuple

3-Tuple `(lat, lon, height)` in `degrees90`, `degrees180` and `meter`, conventionally.

Instance Methods
to4Tuple(self, datum, **name) Extend this LatLon3Tuple to a LatLon4Tuple. |
Inherited from `named._NamedTuple`: `__delattr__`, `__getattr__`, `__hash__`, `__repr__`, `__setattr__`, `__str__`, `dup`, `items`, `iteritems`, `iterunits`, `reUnit`, `toRepr`, `toStr`, `toUnits`, `units` Inherited from `tuple`: `__add__`, `__contains__`, `__eq__`, `__ge__`, `__getattribute__`, `__getitem__`, `__getnewargs__`, `__getslice__`, `__gt__`, `__iter__`, `__le__`, `__len__`, `__lt__`, `__mul__`, `__ne__`, `__rmul__`, `count`, `index` Inherited from `named._Named`: `__format__`, `__imatmul__`, `__matmul__`, `__rmatmul__`, `attrs`, `classof`, `copy`, `methodname`, `rename`, `renamed`, `toStr2` Inherited from `object`: `__init__`, `__reduce__`, `__reduce_ex__`, `__sizeof__`, `__subclasshook__`

Static Methods
Inherited from `named._NamedTuple`: `__new__`

Properties
Inherited from `named._Named`: `classname`, `classnaming`, `iteration`, `name`, `named`, `named2`, `named3`, `named4`, `sizeof`, `typename` Inherited from `object`: `__class__`

Method Details

### to4Tuple (self, datum, **name) |
Extend this LatLon3Tuple to a LatLon4Tuple. Arguments: `datum` - The datum to add (`Datum`). `name` - Optional `name=NN` (`str`), overriding this name. Returns: A LatLon4Tuple`(lat, lon, height, datum)`. Raises: `TypeError` - If `datum` not a `Datum`.